﻿;; CADaSchtroumpf, Bruno Valsecchi; France
;; 2021
;;
;; Изменения оформления - АлексЮстасу
;;
;;
;; ListBox (gile)
;; Boite de dialogue permettant un ou plusieurs choix dans une liste
;;
;; Arguments
;; title : le titre de la boite de dialogue (chaîne)
;; msg ; message (chaîne), "" ou nil pour aucun
;; keylab : une liste d'association du type ((key1 . label1) (key2 . label2) ...)
;; flag : 0 = liste déroulante
;; 1 = liste choix unique
;; 2 = liste choix multipes
;;
;; Retour : la clé de l'option (flag = 0 ou 1) ou la liste des clés des options (flag = 2)
;;
;; Exemple d'utilisation
;; (listbox "Présentation" "Choisir une présentation" (mapcar 'cons (layoutlist) (layoutlist)) 1)
(defun ListBox (title msg keylab flag / tmp file dcl_id choice)
	(setq
		tmp (vl-filename-mktemp "tmp.dcl")
		file (open tmp "w")
	)
	(write-line
		(strcat "ListBox:dialog{label=\"" title "\";")
		file
	)
	(if (and msg (/= msg ""))
		(write-line (strcat ":text{label=\"" msg "\";}") file)
	)
	(write-line
		(cond
			((= 0 flag) "spacer;:popup_list{key=\"lst\";")
			((= 1 flag) "spacer;:list_box{key=\"lst\";")
			(T "spacer;:list_box{key=\"lst\";multiple_select=true;")
		)
		file
	)
	(write-line "}spacer;ok_button;}" file)
	(close file)
	(setq dcl_id (load_dialog tmp))
	(if (not (new_dialog "ListBox" dcl_id))
		(exit)
	)
	(start_list "lst")
	(mapcar 'add_list (mapcar 'cdr keylab))
	(end_list)
	(action_tile
		"accept"
		"(or (= (get_tile \"lst\") \"\")
			(if (= 2 flag)
				(progn
					(foreach n (str2lst (get_tile \"lst\") \" \")
						(setq choice (cons (nth (atoi n) (mapcar 'car keylab)) choice))
					)
					(setq choice (reverse choice))
				)
				(setq choice (nth (atoi (get_tile \"lst\")) (mapcar 'car keylab)))
			)
		)
		(done_dialog)"
	)
	(start_dialog)
	(unload_dialog dcl_id)
	(vl-file-delete tmp)
	choice
)
(defun c:sel_by_apps ( / js n ent_name dxf_ent apps lst_apps sel_app)
	(setq js (ssget "_X" (list (list -3 (list "*")))))
	(cond
		(js
			(repeat (setq n (sslength js))
				(setq
					ent_name (ssname js (setq n (1- n)))
					dxf_ent (entget ent_name (list "*"))
					apps (cdr (assoc -3 dxf_ent))
				)
				(foreach el apps
					(if (not (member (car el) lst_apps)) (setq lst_apps (cons (car el) lst_apps)))
				)
			)
			(setq sel_app (listbox "XData Applications" "Choose application" (mapcar 'cons lst_apps lst_apps) 1))
			(cond
				(sel_app
					(sssetfirst nil (ssget "_X" (list '(0 . "*") (list -3 (list sel_app)))))
				)
			)
		)
	)
	(prin1)
)
(princ "\n  Type in command line: SEL_BY_APPS")
